# Fawoc report

### this is the topic-terms table

{{ topic_terms_table }}

### this is the topic-year table

{{ year_table }}


### this is the graph

![]({{ year_report }})


### this is the journal-topic table

{{ journal_topic_table }}


### this is the journal-year table

{{ journal_year_table }}
